// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module requires `dataset-solid_protocol_0_9` feature to be enabled.

use crate::dataset_from_path;

dataset_from_path!("../../ontologies_ext/solid_protocol_0_9.nq");
